==> sPyNNaker-1!7.0.0a5-py3-none-any.whl: spynnaker/pyNN/extra_algorithms/splitter_components/__init__.py <==
# Copyright (c) 2020 The University of Manchester
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .abstract_spynnaker_splitter_delay import AbstractSpynnakerSplitterDelay
from .spynnaker_splitter_partitioner import spynnaker_splitter_partitioner
from .spynnaker_splitter_selector import spynnaker_splitter_selector
from .splitter_abstract_pop_vertex_fixed import (
    SplitterAbstractPopulationVertexFixed)
from .splitter_delay_vertex_slice import SplitterDelayVertexSlice
from .splitter_abstract_pop_vertex_neurons_synapses import (
    SplitterAbstractPopulationVertexNeuronsSynapses)
from .splitter_poisson_delegate import SplitterPoissonDelegate
from .abstract_supports_one_to_one_sdram_input import (
    AbstractSupportsOneToOneSDRAMInput)

__all__ = [
    'AbstractSpynnakerSplitterDelay', 'SplitterAbstractPopulationVertexFixed',
    'SplitterDelayVertexSlice', 'spynnaker_splitter_partitioner',
    'spynnaker_splitter_selector',
    'SplitterAbstractPopulationVertexNeuronsSynapses',
    'SplitterPoissonDelegate', 'AbstractSupportsOneToOneSDRAMInput',
    'SplitterAbstractPopulationVertexFixed']

==> sPyNNaker-1!7.2.1-py3-none-any.whl: spynnaker/pyNN/extra_algorithms/splitter_components/__init__.py <==
# Copyright (c) 2020 The University of Manchester
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .abstract_spynnaker_splitter_delay import AbstractSpynnakerSplitterDelay
from .spynnaker_splitter_selector import spynnaker_splitter_selector
from .splitter_abstract_pop_vertex import SplitterAbstractPopulationVertex
from .splitter_abstract_pop_vertex_fixed import (
    SplitterAbstractPopulationVertexFixed)
from .splitter_delay_vertex_slice import SplitterDelayVertexSlice
from .splitter_abstract_pop_vertex_neurons_synapses import (
    SplitterAbstractPopulationVertexNeuronsSynapses)
from .splitter_poisson_delegate import SplitterPoissonDelegate
from .abstract_supports_one_to_one_sdram_input import (
    AbstractSupportsOneToOneSDRAMInput)

__all__ = [
    'AbstractSpynnakerSplitterDelay', 'SplitterAbstractPopulationVertex',
    'SplitterDelayVertexSlice', 'spynnaker_splitter_selector',
    'SplitterAbstractPopulationVertexNeuronsSynapses',
    'SplitterPoissonDelegate', 'AbstractSupportsOneToOneSDRAMInput',
    'SplitterAbstractPopulationVertexFixed']
